@@ -19,11 +19,15 @@ class AbstractSpeaker(abc.ABC):
 
     @abc.abstractmethod
     def read_text(self, text: str, **config) -> None:
-        return NotImplementedError("Class %s doesn't implement `read_text()`" % self.__class__.__name__)
+        return NotImplementedError(
+            "Class %s doesn't implement `read_text()`" % self.__class__.__name__
+        )
 
     @abc.abstractmethod
     def stop_text(self) -> None:
-        return NotImplementedError("Class %s doesn't implement `stop_text()`" % self.__class__.__name__)
+        return NotImplementedError(
+            "Class %s doesn't implement `stop_text()`" % self.__class__.__name__
+        )
 
     @classmethod
     def clean_text(cls, text):
