@@ -6,6 +6,7 @@ from PyQt5.QtCore import QUrl
 from PyQt5.QtMultimedia import QMediaContent, QMediaPlaylist
 
 from cracker.mp3_helper import create_filename, save_mp3
+from cracker.speaker import GOOGLE_LANGUAGES
 from cracker.speaker.abstract_speaker import AbstractSpeaker
 from cracker.text_parser import TextParser
 from cracker.utils import get_logger
@@ -20,6 +21,8 @@ class Google(AbstractSpeaker):
     RATES = [80, 120, 160, 200, 240]
     VOLUMES = range(100)
 
+    LANGUAGES = GOOGLE_LANGUAGES
+
     def __init__(self, player, credentials_file: Optional[str] = None):
         self._connect_google(credentials_file)
         self.player = player
@@ -29,7 +32,9 @@ class Google(AbstractSpeaker):
             if credentials_file is not None:
                 self._logger.info("Using credentials file: %s", credentials_file)
                 full_path = os.path.expanduser(credentials_file)
-                self.client = texttospeech.TextToSpeechClient.from_service_account_json(full_path)
+                self.client = texttospeech.TextToSpeechClient.from_service_account_json(
+                    full_path
+                )
             else:
                 self._logger.info("Using default credentials file")
                 self.client = texttospeech.TextToSpeechClient()
@@ -62,9 +67,13 @@ class Google(AbstractSpeaker):
         self.play_files(filepaths)
 
     def ask_google(self, text: str, voice):
-        audio_config = texttospeech.AudioConfig(audio_encoding=texttospeech.AudioEncoding.MP3)
+        audio_config = texttospeech.AudioConfig(
+            audio_encoding=texttospeech.AudioEncoding.MP3
+        )
         synth_speech = texttospeech.SynthesisInput(text=text)
-        response = self.client.synthesize_speech(input=synth_speech, voice=voice, audio_config=audio_config)
+        response = self.client.synthesize_speech(
+            input=synth_speech, voice=voice, audio_config=audio_config
+        )
         return response
 
     def play_files(self, filepaths):
