@@ -1,10 +1,11 @@
 import json
 import logging
+import pkgutil
 from typing import Any, Dict, Optional
 
 from PyQt5.QtWidgets import QCheckBox, QGridLayout, QLabel, QLineEdit, QPushButton, QWidget
 
-from cracker.configuration import Configuration
+from cracker.config import Configuration
 
 
 class ConfigWindow(QWidget):
@@ -61,8 +62,10 @@ class ConfigWindow(QWidget):
 
         regex_config_list = {}
         try:
-            with open(self.regex_file_path) as f:
-                regex_config_list = json.loads(f.read())
+            file_content = pkgutil.get_data("cracker", self.regex_file_path)
+            if file_content is None:
+                raise FileNotFoundError(f"Could not find config file {self.regex_file_path}")
+            regex_config_list = json.loads(file_content.decode("utf-8"))
         except Exception:
             self._logger.exception("While reading config")
 
@@ -82,8 +85,12 @@ class ConfigWindow(QWidget):
         assert self.regex_config, "Regex config hasn't been loaded"
         regex_config_options_layout = self.layout.itemAtPosition(0, 0).widget().layout
         for row in range(1, regex_config_options_layout.rowCount()):
-            active_box = regex_config_options_layout.itemAtPosition(row, RegexConfigOptions.ACTIVE_POS).widget()
-            name_widget = regex_config_options_layout.itemAtPosition(row, RegexConfigOptions.NAME_POS).widget()
+            active_box = regex_config_options_layout.itemAtPosition(
+                row, RegexConfigOptions.ACTIVE_POS
+            ).widget()
+            name_widget = regex_config_options_layout.itemAtPosition(
+                row, RegexConfigOptions.NAME_POS
+            ).widget()
             name = name_widget.text()
             if name in self.regex_config:
                 self.regex_config[name]["active"] = active_box.isChecked()
